.. _release_notes:

Release Notes
=============

v0.1.1 (4 August 2021)
----------------------

Bug fixes
~~~~~~~~~

- Fix selection using indexers with more than one chunk (:pull:`38`).

Maintenance
~~~~~~~~~~~

- Re-enable tests with pys2index on Linux (:pull:`33`).
- Transfer repository to ``xarray-contrib`` organization (:pull:`36`).

v0.1.0 (17 December 2020)
-------------------------

Initial release.
